DynamicLoginPage class
A customizable and reusable login screen widget that supports email/password login, social login, and various UI customization options.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DynamicLoginPage
Constructors
-
DynamicLoginPage(String appLogo, String googleLogo, String facebookLogo, String appleLogo, {Key? key, bool? isEmailValid = false, bool? isPasswordValid = false, bool? isPasswordObscure = true, bool? showGoogleIcon = true, bool? showForgotPassword = true, bool? showFacebookIcon = true, bool? showAppleIcon = true, bool? showOtpOption = true, int? passwordMaxLength = 12, TextEditingController? emailController, TextEditingController? passwordController, Color? themeColor = Colors.deepPurple, VoidCallback? forgotPasswordFunction, VoidCallback? loginFunction, VoidCallback? registerFunction, VoidCallback? facebookLoginFunction, VoidCallback? googleLoginFunction, VoidCallback? appleLoginFunction, VoidCallback? otpFunction, required VoidCallback? passwordVisibilityFunction, required GlobalKey<
FormState> emailFormKey, required GlobalKey<FormState> passwordFormKey}) -
const
Properties
- appleLoginFunction → VoidCallback?
-
final
- appleLogo → String?
-
final
- appLogo → String?
-
final
- emailController → TextEditingController?
-
final
-
emailFormKey
→ GlobalKey<
FormState> -
final
- facebookLoginFunction → VoidCallback?
-
final
- facebookLogo → String?
-
final
- forgotPasswordFunction → VoidCallback?
-
final
- googleLoginFunction → VoidCallback?
-
final
- googleLogo → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmailValid → bool?
-
final
- isPasswordObscure → bool?
-
final
- isPasswordValid → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loginFunction → VoidCallback?
-
final
- otpFunction → VoidCallback?
-
final
- passwordController → TextEditingController?
-
final
-
passwordFormKey
→ GlobalKey<
FormState> -
final
- passwordMaxLength → int?
-
final
- passwordVisibilityFunction → VoidCallback?
-
final
- registerFunction → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAppleIcon → bool?
-
final
- showFacebookIcon → bool?
-
final
- showForgotPassword → bool?
-
final
- showGoogleIcon → bool?
-
final
- showOtpOption → bool?
-
final
- themeColor → Color?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DynamicLoginPage> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited